==> YNQ-1.5.1_Linux_S_CP.zip: YNQ-1.5.1_Linux_S_CP/NQ Library Reference/html/search/all_66.js <==
var searchData=
[
  ['file_20access_20mode',['File access mode',['../group__access.html',1,'']]],
  ['file_20attributes',['File attributes',['../group__attributes.html',1,'']]],
  ['file_20create_20action',['File create action',['../group__create.html',1,'']]],
  ['fields',['fields',['../structSYDeviceMode.html#a1a7161f37f79269281e463f1cd5e6bea',1,'SYDeviceMode']]],
  ['file_20operations',['File Operations',['../group__file.html',1,'']]],
  ['file_5fam_5fread',['FILE_AM_READ',['../group__access.html#ga601fdadf27fca92cbada25cc3c3c0bb4',1,'ccapi.h']]],
  ['file_5fam_5fread_5fwrite',['FILE_AM_READ_WRITE',['../group__access.html#ga545552a912259ec55b7f5582863b428a',1,'ccapi.h']]],
  ['file_5fam_5fspecial_5fmask',['FILE_AM_SPECIAL_MASK',['../group__access.html#ga4a40b34f62bbf0ed4aa3275168b5a62d',1,'ccapi.h']]],
  ['file_5fam_5fwrite',['FILE_AM_WRITE',['../group__access.html#ga9ff6f005e453e478c044b70480e6a283',1,'ccapi.h']]],
  ['file_20attributes',['File Attributes',['../group__file__attr.html',1,'']]],
  ['file_5fca_5fcreate',['FILE_CA_CREATE',['../group__create.html#gad8ac4a86a53517fcf48214860209d198',1,'ccapi.h']]],
  ['file_5fca_5ffail',['FILE_CA_FAIL',['../group__create.html#ga512fdc9993e25f5de7f54bf5008c9c96',1,'ccapi.h']]],
  ['file_20information',['File Information',['../group__file__info.html',1,'']]],
  ['file_5flcl_5fmixed',['FILE_LCL_MIXED',['../group__locality.html#ga8c53c4faed37579cd4799ac2396bca76',1,'ccapi.h']]],
  ['file_5flcl_5frandom',['FILE_LCL_RANDOM',['../group__locality.html#ga59ca52168596a283c1ef2bae68d5be33',1,'ccapi.h']]],
  ['file_5flcl_5fsequential',['FILE_LCL_SEQUENTIAL',['../group__locality.html#gacfdffe127c41ba179d07039e9b6964c9',1,'ccapi.h']]],
  ['file_5flcl_5funknown',['FILE_LCL_UNKNOWN',['../group__locality.html#gaf737af91134f0e2ee823fc9a45b04da1',1,'ccapi.h']]],
  ['file_20locking',['File Locking',['../group__file__locking.html',1,'']]],
  ['file_5foa_5ffail',['FILE_OA_FAIL',['../group__open.html#ga632943f748398bd9a6f4c50adbd0d028',1,'ccapi.h']]],
  ['file_5foa_5fopen',['FILE_OA_OPEN',['../group__open.html#ga54137326199ec072a38c304a89aacbb4',1,'ccapi.h']]],
  ['file_5foa_5ftruncate',['FILE_OA_TRUNCATE',['../group__open.html#gafa977d37529866e1b998fcfe6c3d3f10',1,'ccapi.h']]],
  ['file_5fsm_5fcompat',['FILE_SM_COMPAT',['../group__share.html#gadffb1ccdecd75cf369004821e63837fb',1,'ccapi.h']]],
  ['file_5fsm_5fdeny_5fnone',['FILE_SM_DENY_NONE',['../group__share.html#ga2e1f19d8c36caab547c559f3a922d89e',1,'ccapi.h']]],
  ['file_5fsm_5fdeny_5fread',['FILE_SM_DENY_READ',['../group__share.html#gaedebb4176eb1600c5d69bb7ddb6daa11',1,'ccapi.h']]],
  ['file_5fsm_5fdeny_5fwrite',['FILE_SM_DENY_WRITE',['../group__share.html#gaea181bf321f0044d57d780063a9ba2c2',1,'ccapi.h']]],
  ['file_5fsm_5fexclusive',['FILE_SM_EXCLUSIVE',['../group__share.html#gad25693a9187308c31dbbe98bd56d9c03',1,'ccapi.h']]],
  ['fileattributes',['fileAttributes',['../structCCFindFileDataA.html#a9178b094573498cb9b27722c6e6f3643',1,'CCFindFileDataA::fileAttributes()'],['../structCCFindFileData.html#a06402524226e668b5b467b6b9b5f078d',1,'CCFindFileData::fileAttributes()']]],
  ['filedataa_5ft',['FileDataA_t',['../structFileDataA__t.html',1,'']]],
  ['fileidhigh',['fileIdHigh',['../structSYFileInformation.html#a1ae1a6ff7921b7cb0a9f746e52b999d2',1,'SYFileInformation']]],
  ['fileidlow',['fileIdLow',['../structSYFileInformation.html#a62248f37bee1de27aebb92824e36cca0',1,'SYFileInformation']]],
  ['fileindex',['fileIndex',['../structCCFileInfo.html#ac5ae587f4f73de08bb98305895c5369a',1,'CCFileInfo']]],
  ['fileindexhigh',['fileIndexHigh',['../structCCFileInfo__t.html#a6a3168ee6b2d5f4b5509b310b7f90977',1,'CCFileInfo_t']]],
  ['fileindexlow',['fileIndexLow',['../structCCFileInfo__t.html#a129e0a3313007736bd59c055d769d9e4',1,'CCFileInfo_t']]],
  ['fileinfo_5ft',['FileInfo_t',['../group__info.html#ga3c9b28c0af2e8615493cafd244b07489',1,'ccapi.h']]],
  ['filename',['fileName',['../structCCFindFileDataA.html#a97db246a36afb881c65af2521a55acad',1,'CCFindFileDataA::fileName()'],['../structCCFindFileData.html#a76a169664f5fab5ac34438a7b5c334fe',1,'CCFindFileData::fileName()'],['../structEVCSOpenFileEntry.html#a67c549ddce2576ced17a688b895bc23e',1,'EVCSOpenFileEntry::fileName()'],['../structUDFileAccessEvent.html#af39ac82545716a5fd3df056870e5b9cc',1,'UDFileAccessEvent::fileName()']]],
  ['filenamelength',['fileNameLength',['../structCCFindFileDataA.html#acf63655cfd1132859bd6f04d8757adf3',1,'CCFindFileDataA::fileNameLength()'],['../structCCFindFileData.html#a16cda0bfb564dcb05129a55958ea74a9',1,'CCFindFileData::fileNameLength()']]],
  ['filenamepath',['fileNamePath',['../structFileDataA__t.html#a839256bce91b47970f5fec9994c986d9',1,'FileDataA_t::fileNamePath()'],['../structCSFileData.html#a24d6b85c3f4fd7d347b1483dd2cd6f99',1,'CSFileData::fileNamePath()']]],
  ['files',['Files',['../group__files.html',1,'']]],
  ['filesizehigh',['fileSizeHigh',['../structCCFindFileDataA.html#a366ef90cc577494b67ba5513a10ba36f',1,'CCFindFileDataA::fileSizeHigh()'],['../structCCFindFileData.html#a9abd5cdc8f1adb8c943a7060beb94afc',1,'CCFindFileData::fileSizeHigh()'],['../structCCFileInfo__t.html#ad74dbdf6b86ed4f66557a99d792f16ac',1,'CCFileInfo_t::fileSizeHigh()']]],
  ['filesizelow',['fileSizeLow',['../structCCFindFileDataA.html#a56471dceec07d8a8d11360db7302c92b',1,'CCFindFileDataA::fileSizeLow()'],['../structCCFindFileData.html#ac33e9071d16afab6b455e0d7b87bfe99',1,'CCFindFileData::fileSizeLow()'],['../structCCFileInfo__t.html#aa3b1f635a9cfbb0f4c9387a9107762db',1,'CCFileInfo_t::fileSizeLow()']]],
  ['filesystemidhigh',['fileSystemIdHigh',['../structSYVolumeInformation.html#abf7fbba608722bdf15b94aa0785545ac',1,'SYVolumeInformation']]],
  ['filesystemidlow',['fileSystemIdLow',['../structSYVolumeInformation.html#aea7c4ca8ecb227f8b0b2f07a8a272d04',1,'SYVolumeInformation']]],
  ['findfiledataa_5ft',['FindFileDataA_t',['../group__search.html#ga9de516127e39d186b2857d38ffd5b40c',1,'ccapi.h']]],
  ['flags',['flags',['../structSYPrinterInfo.html#a4e2fab6285a56e19c28de5f2f8e3de88',1,'SYPrinterInfo::flags()'],['../structSYPrintFormInfo.html#a6121961ce238365207c8d46a844bc2f7',1,'SYPrintFormInfo::flags()']]],
  ['formname',['formName',['../structSYDeviceMode.html#ae0a9259c5b5d2301827c83f812ca8021',1,'SYDeviceMode']]],
  ['freeclusters',['freeClusters',['../structCCVolumeInfo.html#a06601afbc4f97b52eac75dcebffeb132',1,'CCVolumeInfo']]],
  ['freeunitshigh',['freeUnitsHigh',['../structSYVolumeInformation.html#a2af4bda69c4ae7ff0107ee59a4db16d1',1,'SYVolumeInformation']]],
  ['freeunitslow',['freeUnitsLow',['../structSYVolumeInformation.html#a443f6c7dbbe96bd4924f286b07948d9a',1,'SYVolumeInformation']]],
  ['fstoansi',['fsToAnsi',['../structCMCodepage.html#a54c32d6bb31ef13a2c128a7330e3316f',1,'CMCodepage']]],
  ['fstype',['fsType',['../structCCVolumeInfo.html#a260430fa3b559d30c1fa5de458b78c3b',1,'CCVolumeInfo']]],
  ['functions',['Functions',['../group__functions.html',1,'']]],
  ['file_20info_20operations',['File Info Operations',['../group__info.html',1,'']]],
  ['file_20locality',['File locality',['../group__locality.html',1,'']]],
  ['file_20open_20action',['File open action',['../group__open.html',1,'']]],
  ['file_20seek_20constants',['File seek constants',['../group__seek.html',1,'']]],
  ['file_20share_20mode',['File share mode',['../group__share.html',1,'']]]
];

==> YNQ-1.6.0_Linux_S_CP.zip: YNQ-1.6.0_Linux_S_CP/NQ Library Reference/html/search/all_66.js <==
var searchData=
[
  ['file_20access_20mode',['File Access Mode',['../group__access.html',1,'']]],
  ['file_20attributes',['File Attributes',['../group__attributes.html',1,'']]],
  ['file_20create_20action',['File Create Action',['../group__create.html',1,'']]],
  ['fields',['fields',['../structSYDeviceMode.html#a1a7161f37f79269281e463f1cd5e6bea',1,'SYDeviceMode']]],
  ['file_20operations',['File Operations',['../group__file.html',1,'']]],
  ['file_5fam_5fread',['FILE_AM_READ',['../group__access.html#ga601fdadf27fca92cbada25cc3c3c0bb4',1,'ccapi.h']]],
  ['file_5fam_5fread_5fwrite',['FILE_AM_READ_WRITE',['../group__access.html#ga545552a912259ec55b7f5582863b428a',1,'ccapi.h']]],
  ['file_5fam_5fspecial_5fmask',['FILE_AM_SPECIAL_MASK',['../group__access.html#ga4a40b34f62bbf0ed4aa3275168b5a62d',1,'ccapi.h']]],
  ['file_5fam_5fwrite',['FILE_AM_WRITE',['../group__access.html#ga9ff6f005e453e478c044b70480e6a283',1,'ccapi.h']]],
  ['file_20attributes',['File Attributes',['../group__file__attr.html',1,'']]],
  ['file_5fca_5fcreate',['FILE_CA_CREATE',['../group__create.html#gad8ac4a86a53517fcf48214860209d198',1,'ccapi.h']]],
  ['file_5fca_5ffail',['FILE_CA_FAIL',['../group__create.html#ga512fdc9993e25f5de7f54bf5008c9c96',1,'ccapi.h']]],
  ['file_20information',['File Information',['../group__file__info.html',1,'']]],
  ['file_5flcl_5fmixed',['FILE_LCL_MIXED',['../group__locality.html#ga8c53c4faed37579cd4799ac2396bca76',1,'ccapi.h']]],
  ['file_5flcl_5frandom',['FILE_LCL_RANDOM',['../group__locality.html#ga59ca52168596a283c1ef2bae68d5be33',1,'ccapi.h']]],
  ['file_5flcl_5fsequential',['FILE_LCL_SEQUENTIAL',['../group__locality.html#gacfdffe127c41ba179d07039e9b6964c9',1,'ccapi.h']]],
  ['file_5flcl_5funknown',['FILE_LCL_UNKNOWN',['../group__locality.html#gaf737af91134f0e2ee823fc9a45b04da1',1,'ccapi.h']]],
  ['file_20locking',['File Locking',['../group__file__locking.html',1,'']]],
  ['file_5foa_5ffail',['FILE_OA_FAIL',['../group__open.html#ga632943f748398bd9a6f4c50adbd0d028',1,'ccapi.h']]],
  ['file_5foa_5fopen',['FILE_OA_OPEN',['../group__open.html#ga54137326199ec072a38c304a89aacbb4',1,'ccapi.h']]],
  ['file_5foa_5ftruncate',['FILE_OA_TRUNCATE',['../group__open.html#gafa977d37529866e1b998fcfe6c3d3f10',1,'ccapi.h']]],
  ['file_5fsm_5fcompat',['FILE_SM_COMPAT',['../group__share.html#gadffb1ccdecd75cf369004821e63837fb',1,'ccapi.h']]],
  ['file_5fsm_5fdeny_5fnone',['FILE_SM_DENY_NONE',['../group__share.html#ga2e1f19d8c36caab547c559f3a922d89e',1,'ccapi.h']]],
  ['file_5fsm_5fdeny_5fread',['FILE_SM_DENY_READ',['../group__share.html#gaedebb4176eb1600c5d69bb7ddb6daa11',1,'ccapi.h']]],
  ['file_5fsm_5fdeny_5fwrite',['FILE_SM_DENY_WRITE',['../group__share.html#gaea181bf321f0044d57d780063a9ba2c2',1,'ccapi.h']]],
  ['file_5fsm_5fexclusive',['FILE_SM_EXCLUSIVE',['../group__share.html#gad25693a9187308c31dbbe98bd56d9c03',1,'ccapi.h']]],
  ['fileattributes',['fileAttributes',['../structCCFindFileDataA.html#a9178b094573498cb9b27722c6e6f3643',1,'CCFindFileDataA::fileAttributes()'],['../structCCFindFileData.html#a06402524226e668b5b467b6b9b5f078d',1,'CCFindFileData::fileAttributes()']]],
  ['filedataa_5ft',['FileDataA_t',['../structFileDataA__t.html',1,'']]],
  ['fileidhigh',['fileIdHigh',['../structSYFileInformation.html#a1ae1a6ff7921b7cb0a9f746e52b999d2',1,'SYFileInformation']]],
  ['fileidlow',['fileIdLow',['../structSYFileInformation.html#a62248f37bee1de27aebb92824e36cca0',1,'SYFileInformation']]],
  ['fileindex',['fileIndex',['../structCCFileInfo.html#ac5ae587f4f73de08bb98305895c5369a',1,'CCFileInfo']]],
  ['fileindexhigh',['fileIndexHigh',['../structCCFileInfo__t.html#a6a3168ee6b2d5f4b5509b310b7f90977',1,'CCFileInfo_t']]],
  ['fileindexlow',['fileIndexLow',['../structCCFileInfo__t.html#a129e0a3313007736bd59c055d769d9e4',1,'CCFileInfo_t']]],
  ['fileinfo_5ft',['FileInfo_t',['../group__info.html#ga3c9b28c0af2e8615493cafd244b07489',1,'ccapi.h']]],
  ['filename',['fileName',['../structCCFindFileDataA.html#a97db246a36afb881c65af2521a55acad',1,'CCFindFileDataA::fileName()'],['../structCCFindFileData.html#a76a169664f5fab5ac34438a7b5c334fe',1,'CCFindFileData::fileName()'],['../structEVCSOpenFileEntry.html#a67c549ddce2576ced17a688b895bc23e',1,'EVCSOpenFileEntry::fileName()'],['../structUDFileAccessEvent.html#af39ac82545716a5fd3df056870e5b9cc',1,'UDFileAccessEvent::fileName()']]],
  ['filenamelength',['fileNameLength',['../structCCFindFileDataA.html#acf63655cfd1132859bd6f04d8757adf3',1,'CCFindFileDataA::fileNameLength()'],['../structCCFindFileData.html#a16cda0bfb564dcb05129a55958ea74a9',1,'CCFindFileData::fileNameLength()']]],
  ['filenamepath',['fileNamePath',['../structFileDataA__t.html#a839256bce91b47970f5fec9994c986d9',1,'FileDataA_t::fileNamePath()'],['../structCSFileData.html#a24d6b85c3f4fd7d347b1483dd2cd6f99',1,'CSFileData::fileNamePath()']]],
  ['files',['Files',['../group__files.html',1,'']]],
  ['filesizehigh',['fileSizeHigh',['../structCCFindFileDataA.html#a366ef90cc577494b67ba5513a10ba36f',1,'CCFindFileDataA::fileSizeHigh()'],['../structCCFindFileData.html#a9abd5cdc8f1adb8c943a7060beb94afc',1,'CCFindFileData::fileSizeHigh()'],['../structCCFileInfo__t.html#ad74dbdf6b86ed4f66557a99d792f16ac',1,'CCFileInfo_t::fileSizeHigh()']]],
  ['filesizelow',['fileSizeLow',['../structCCFindFileDataA.html#a56471dceec07d8a8d11360db7302c92b',1,'CCFindFileDataA::fileSizeLow()'],['../structCCFindFileData.html#ac33e9071d16afab6b455e0d7b87bfe99',1,'CCFindFileData::fileSizeLow()'],['../structCCFileInfo__t.html#aa3b1f635a9cfbb0f4c9387a9107762db',1,'CCFileInfo_t::fileSizeLow()']]],
  ['filesystemidhigh',['fileSystemIdHigh',['../structSYVolumeInformation.html#abf7fbba608722bdf15b94aa0785545ac',1,'SYVolumeInformation']]],
  ['filesystemidlow',['fileSystemIdLow',['../structSYVolumeInformation.html#aea7c4ca8ecb227f8b0b2f07a8a272d04',1,'SYVolumeInformation']]],
  ['findfiledataa_5ft',['FindFileDataA_t',['../group__search.html#ga9de516127e39d186b2857d38ffd5b40c',1,'ccapi.h']]],
  ['flags',['flags',['../structSYPrinterInfo.html#a4e2fab6285a56e19c28de5f2f8e3de88',1,'SYPrinterInfo::flags()'],['../structSYPrintFormInfo.html#a6121961ce238365207c8d46a844bc2f7',1,'SYPrintFormInfo::flags()']]],
  ['formname',['formName',['../structSYDeviceMode.html#ae0a9259c5b5d2301827c83f812ca8021',1,'SYDeviceMode']]],
  ['freeclusters',['freeClusters',['../structCCVolumeInfo.html#a06601afbc4f97b52eac75dcebffeb132',1,'CCVolumeInfo']]],
  ['freeunitshigh',['freeUnitsHigh',['../structSYVolumeInformation.html#a2af4bda69c4ae7ff0107ee59a4db16d1',1,'SYVolumeInformation']]],
  ['freeunitslow',['freeUnitsLow',['../structSYVolumeInformation.html#a443f6c7dbbe96bd4924f286b07948d9a',1,'SYVolumeInformation']]],
  ['fstoansi',['fsToAnsi',['../structCMCodepage.html#a54c32d6bb31ef13a2c128a7330e3316f',1,'CMCodepage']]],
  ['fstype',['fsType',['../structCCVolumeInfo.html#a260430fa3b559d30c1fa5de458b78c3b',1,'CCVolumeInfo']]],
  ['functions',['Functions',['../group__functions.html',1,'']]],
  ['file_20info_20operations',['File Info Operations',['../group__info.html',1,'']]],
  ['file_20locality',['File Locality',['../group__locality.html',1,'']]],
  ['file_20open_20action',['File Open Action',['../group__open.html',1,'']]],
  ['file_20seek_20constants',['File Seek Constants',['../group__seek.html',1,'']]],
  ['file_20share_20mode',['File Share Mode',['../group__share.html',1,'']]]
];
